@@ -18,6 +18,7 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """Dependency Command Module."""
+
 from __future__ import annotations
 
 import logging
@@ -51,30 +52,15 @@ class Dependency(base.Base):
 
 @base.click_command_ex()
 @click.pass_context
-@click.option(
-    "--scenario-name",
-    "-s",
-    multiple=True,
-    default=[base.MOLECULE_DEFAULT_SCENARIO_NAME],
-    help=f"Name of the scenario to target. May be specified multiple times. ({base.MOLECULE_DEFAULT_SCENARIO_NAME})",
-)
-@click.option(
-    "--all/--no-all",
-    "__all",
-    default=False,
-    help="Target all scenarios. Default is False.",
-)
-@click.option(
-    "--exclude",
-    "-e",
-    multiple=True,
-    help="Name of the scenario to exclude from running. May be specified multiple times.",
-)
+@base.click_command_options
 def dependency(
     ctx: click.Context,
+    /,
     scenario_name: list[str] | None,
     exclude: list[str],
-    __all: bool,  # noqa: FBT001
+    *,
+    __all: bool,
+    report: bool,
 ) -> None:  # pragma: no cover
     """Manage the role's dependencies.
 
@@ -83,10 +69,11 @@ def dependency(
         scenario_name: Name of the scenario to target.
         exclude: Name of the scenarios to avoid targeting.
         __all: Whether molecule should target scenario_name or all scenarios.
+        report: Whether to show an after-run summary report.
     """
     args: MoleculeArgs = ctx.obj.get("args")
     subcommand = base._get_subcommand(__name__)  # noqa: SLF001
-    command_args: CommandArgs = {"subcommand": subcommand}
+    command_args: CommandArgs = {"subcommand": subcommand, "report": report}
 
     if __all:
         scenario_name = None
