@@ -18,6 +18,7 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """Login Command Module."""
+
 from __future__ import annotations
 
 import logging
@@ -29,8 +30,9 @@ from typing import TYPE_CHECKING
 
 import click
 
-from molecule import scenarios, util
+from molecule import scenarios
 from molecule.command import base
+from molecule.exceptions import MoleculeError
 
 
 if TYPE_CHECKING:
@@ -79,15 +81,12 @@ class Login(base.Base):
                     "which with --host.\n\n"
                     f"Available hosts:\n{host_list}"
                 )
-                util.sysexit_with_message(msg)
+                raise MoleculeError(msg)
         match = [x for x in hosts if x.startswith(hostname)]
         if len(match) == 0:
-            msg = (
-                f"There are no hosts that match '{hostname}'.  You "
-                "can only login to valid hosts."
-            )
-            util.sysexit_with_message(msg)
-        elif len(match) != 1:
+            msg = f"There are no hosts that match '{hostname}'.  You can only login to valid hosts."
+            raise MoleculeError(msg)
+        if len(match) != 1:
             # If there are multiple matches, but one of them is an exact string
             # match, assume this is the one they're looking for and use it.
             if hostname in match:
@@ -98,7 +97,7 @@ class Login(base.Base):
                     "can only login to one at a time.\n\n"
                     f"Available hosts:\n{host_list}"
                 )
-                util.sysexit_with_message(msg)
+                raise MoleculeError(msg)
 
         return match[0]
 
@@ -110,7 +109,7 @@ class Login(base.Base):
         login_options["lines"] = lines
         if not self._config.driver.login_cmd_template:
             LOG.warning(
-                "Login command is not supported for [dim]%s[/] host because 'login_cmd_template' was not defined in driver options.",  # noqa: E501
+                "Login command is not supported for [dim]%s[/] host because 'login_cmd_template' was not defined in driver options.",
                 login_options["instance"],
             )
             return
@@ -146,6 +145,6 @@ def login(
     subcommand = base._get_subcommand(__name__)  # noqa: SLF001
     command_args: CommandArgs = {"subcommand": subcommand, "host": host}
 
-    s = scenarios.Scenarios(base.get_configs(args, command_args), scenario_name)
+    s = scenarios.Scenarios(base.get_configs(args, command_args), [scenario_name])
     for scenario in s.all:
         base.execute_subcommand(scenario.config, subcommand)
