@@ -18,6 +18,7 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """Delegated Driver Module."""
+
 from __future__ import annotations
 
 import logging
@@ -192,11 +193,7 @@ class Delegated(Driver):
             connection_options = " ".join(self.ssh_connection_options)
 
             return (
-                "ssh {address} "
-                "-l {user} "
-                "-p {port} "
-                "-i {identity_file} "
-                f"{connection_options}"
+                f"ssh {{address}} -l {{user}} -p {{port}} -i {{identity_file}} {connection_options}"
             )
         return ""
 
@@ -282,7 +279,7 @@ class Delegated(Driver):
                     conn_dict["ansible_private_key_file"] = d.get("identity_file")
                 if d.get("password", None):
                     conn_dict["ansible_password"] = d.get("password")
-                    # Based on testinfra documentation, ansible password must be passed via ansible_ssh_pass  # noqa: E501
+                    # Based on testinfra documentation, ansible password must be passed via ansible_ssh_pass
                     # issue to fix this can be found https://github.com/pytest-dev/pytest-testinfra/issues/580
                     conn_dict["ansible_ssh_pass"] = d.get("password")
 
